==> igniteui-react-inputs-18.6.1.tgz: package/esm5/lib/XIconButtonBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XButtonBridge } from "./XButtonBridge";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { XIconBridge } from "./XIconBridge";
import { BaseControlTheme_$type } from "igniteui-react-core";
/**
 * @hidden
 */
var XIconButtonBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XIconButtonBridge, _super);
    function XIconButtonBridge(a, b) {
        var _this = _super.call(this, a) || this;
        _this.al = null;
        _this.al = new XIconBridge(b);
        return _this;
    }
    XIconButtonBridge.prototype.getTargetForBuildInProperty = function (a, b) {
        switch (b) {
            case 15:
            case 16:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49: return this.al.t;
        }
        return _super.prototype.getTargetForBuildInProperty.call(this, a, b);
    };
    XIconButtonBridge.prototype.getTargetForProperty = function (a, b) {
        switch (a) {
            case 16:
            case 15:
            case 17: return this.al.t.view.s;
        }
        return _super.prototype.getTargetForProperty.call(this, a, b);
    };
    XIconButtonBridge.prototype.getValue = function (a, b) {
        switch (b) {
            case 16:
            case 15:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49: return this.al.getValue(a, b);
            case 18: return enumGetBox(BaseControlTheme_$type, a.n);
        }
        return _super.prototype.getValue.call(this, a, b);
    };
    XIconButtonBridge.prototype.setValue = function (a, b, c) {
        _super.prototype.setValue.call(this, a, b, c);
        switch (b) {
            case 16:
            case 15:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
                this.al.setValue(a, b, c);
                break;
            case 18:
                a.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                break;
        }
    };
    XIconButtonBridge.$t = markType(XIconButtonBridge, 'XIconButtonBridge', XButtonBridge.$);
    return XIconButtonBridge;
}(XButtonBridge));
export { XIconButtonBridge };

==> igniteui-react-inputs-18.7.3.tgz: package/esm5/lib/XIconButtonBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XButtonBridge } from "./XButtonBridge";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { XIconBridge } from "./XIconBridge";
import { BaseControlTheme_$type } from "igniteui-react-core";
/**
 * @hidden
 */
var XIconButtonBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XIconButtonBridge, _super);
    function XIconButtonBridge(a, b) {
        var _this = _super.call(this, a) || this;
        _this.al = null;
        _this.al = new XIconBridge(b);
        return _this;
    }
    XIconButtonBridge.prototype.getTargetForBuildInProperty = function (a, b) {
        switch (b) {
            case 15:
            case 16:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49: return this.al.t;
        }
        return _super.prototype.getTargetForBuildInProperty.call(this, a, b);
    };
    XIconButtonBridge.prototype.getTargetForProperty = function (a, b) {
        switch (a) {
            case 16:
            case 15:
            case 17: return this.al.t.view.v;
        }
        return _super.prototype.getTargetForProperty.call(this, a, b);
    };
    XIconButtonBridge.prototype.getValue = function (a, b) {
        switch (b) {
            case 16:
            case 15:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49: return this.al.getValue(a, b);
            case 18: return enumGetBox(BaseControlTheme_$type, a.n);
        }
        return _super.prototype.getValue.call(this, a, b);
    };
    XIconButtonBridge.prototype.setValue = function (a, b, c) {
        _super.prototype.setValue.call(this, a, b, c);
        switch (b) {
            case 16:
            case 15:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
                this.al.setValue(a, b, c);
                break;
            case 18:
                a.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                break;
        }
    };
    XIconButtonBridge.$t = markType(XIconButtonBridge, 'XIconButtonBridge', XButtonBridge.$);
    return XIconButtonBridge;
}(XButtonBridge));
export { XIconButtonBridge };
